@@ -9,13 +9,26 @@ module MCollective
       def startup_hook
         configfile = @config.pluginconf.fetch("puppet.config", nil)
 
-        @puppet_command = @config.pluginconf.fetch("puppet.command", "puppet agent")
+        @puppet_command = @config.pluginconf.fetch("puppet.command", default_agent_command)
         @puppet_service = @config.pluginconf.fetch("puppet.windows_service", "puppet")
         @puppet_splaylimit = Integer(@config.pluginconf.fetch("puppet.splaylimit", 30))
-        @puppet_splay = @config.pluginconf.fetch("puppet.splay", "true")
+        @puppet_splay = Util.str_to_bool(@config.pluginconf.fetch("puppet.splay", "true"))
         @puppet_agent = Util::PuppetAgentMgr.manager(configfile, @puppet_service)
       end
 
+      # Determines the default command to run for puppet agent
+      #
+      # On windows the installer sets up the Path so this should
+      # work with default relying on the path, AIO on Unix does not
+      # so check those and default to that
+      def default_agent_command
+        if File.exist?("/opt/puppetlabs/bin/puppet")
+          "/opt/puppetlabs/bin/puppet agent"
+        else
+          "puppet agent"
+        end
+      end
+
       def run(command, options)
         if MCollective::Util.windows?
           require 'win32/process'
@@ -74,7 +87,7 @@ module MCollective
       action "last_run_summary" do
         summary = @puppet_agent.load_summary
 
-        if request[:parse_log]
+        if request[:logs]
           reply[:logs] = @puppet_agent.last_run_logs
         else
           reply[:logs] = {}
@@ -83,6 +96,7 @@ module MCollective
         reply[:type_distribution]     = @puppet_agent.managed_resource_type_distribution
         reply[:out_of_sync_resources] = summary["resources"].fetch("out_of_sync", 0)
         reply[:failed_resources]      = summary["resources"].fetch("failed", 0)
+        reply[:corrected_resources]   = summary["resources"].fetch("corrective_change", 0)
         reply[:changed_resources]     = summary["resources"].fetch("changed", 0)
         reply[:total_resources]       = summary["resources"].fetch("total", 0)
         reply[:total_time]            = summary["time"].fetch("total", 0)
@@ -100,9 +114,8 @@ module MCollective
       end
 
       action "resource" do
-        allow_managed_resources_management = \
-          !!@config.pluginconf.fetch("puppet.resource_allow_managed_resources",
-                                     "false").match(/^1|true|yes/)
+        allow_managed_resources_management = Util.str_to_bool(
+          @config.pluginconf.fetch("puppet.resource_allow_managed_resources", "false"))
         resource_types_whitelist = \
           @config.pluginconf.fetch("puppet.resource_type_whitelist", nil)
         resource_types_blacklist = \
@@ -200,14 +213,20 @@ module MCollective
         args[:options_only] = true
         args[:noop] = request[:noop] if request.include?(:noop)
         args[:environment] = request[:environment] if request[:environment]
-        args[:server] = request[:server] if request[:server]
+        if request[:server]
+          if Util.str_to_bool(@config.pluginconf.fetch("puppet.allow_server_override","false"))
+            args[:server] = request[:server]
+          else
+            reply.fail!(reply[:summary] = "Passing 'server' option is not allowed in module configuration")
+          end
+        end
         args[:tags] = request[:tags].split(",").map{|t| t.strip} if request[:tags]
         args[:ignoreschedules] = request[:ignoreschedules] if request[:ignoreschedules]
         args[:signal_daemon] = false if MCollective::Util.windows?
         args[:use_cached_catalog] = request[:use_cached_catalog] if request.include?(:use_cached_catalog)
 
         # we can only pass splay arguments if the daemon isn't in signal mode :(
-        signal_daemon = Util.str_to_bool(@config.pluginconf.fetch("puppet.signal_daemon","true")) 
+        signal_daemon = Util.str_to_bool(@config.pluginconf.fetch("puppet.signal_daemon","true"))
         unless @puppet_agent.status[:daemon_present] && signal_daemon
           if request[:force] == true
             # forcing implies --no-splay
@@ -218,7 +237,7 @@ module MCollective
             args[:splaylimit] = request[:splaylimit] if request.include?(:splaylimit)
 
             unless args.include?(:splay)
-              args[:splay] = !!(@puppet_splay =~ /^1|true|yes/)
+              args[:splay] = @puppet_splay
             end
 
             if !args.include?(:splaylimit) && args[:splay]
